@@ -11,6 +11,8 @@
 */
 
 #include "akonadicollectionview.h"
+#include "collectionsortfilterproxymodel.h"
+#include "config-korganizer.h"
 #include "kocore.h"
 #include "koglobals.h"
 #include "kohelper.h"
@@ -53,7 +55,10 @@
 #include <QLineEdit>
 #include <QStackedWidget>
 #include <QVBoxLayout>
-
+#if HAVE_ACTIVITY_SUPPORT
+#include "activities/accountactivities.h"
+#include "activities/activitiesmanager.h"
+#endif
 static Akonadi::EntityTreeModel *findEtm(QAbstractItemModel *model)
 {
     QAbstractProxyModel *proxyModel = nullptr;
@@ -218,7 +223,6 @@ private:
 
 AkonadiCollectionViewFactory::AkonadiCollectionViewFactory(CalendarView *view)
     : mView(view)
-    , mAkonadiCollectionView(nullptr)
 {
 }
 
@@ -307,7 +311,6 @@ public:
     explicit CollectionFilter(QObject *parent = nullptr)
         : QSortFilterProxyModel(parent)
     {
-        setDynamicSortFilter(true);
     }
 
 protected:
@@ -413,7 +416,6 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
 
     auto colorProxy = new ColorProxyModel(this);
     colorProxy->setObjectName(QLatin1StringView("Show calendar colors"));
-    colorProxy->setDynamicSortFilter(true);
     mBaseModel = colorProxy;
 
     auto calendarDelegateModel = new CalendarDelegateModel(this);
@@ -428,10 +430,13 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
     searchProxy->setSourceModel(collectionFilter);
     searchProxy->setObjectName(QLatin1StringView("searchProxy"));
 
-    auto filterTreeViewModel = new QSortFilterProxyModel(this);
+    auto filterTreeViewModel = new CollectionSortFilterProxyModel(this);
+#if HAVE_ACTIVITY_SUPPORT
+    filterTreeViewModel->setAccountActivities(ActivitiesManager::self()->accountActivities());
+#endif
+    // TODO add activities support
     filterTreeViewModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
     filterTreeViewModel->setRecursiveFilteringEnabled(true);
-    filterTreeViewModel->setDynamicSortFilter(true);
     filterTreeViewModel->setSourceModel(searchProxy);
     connect(searchCol, &QLineEdit::textChanged, filterTreeViewModel, &QSortFilterProxyModel::setFilterWildcard);
 
