@@ -64,12 +64,15 @@ public:
     KCheckableProxyModel *collectionSelectionProxyModel() const;
     void setCollectionSelectionProxyModel(KCheckableProxyModel *);
 
-    Q_REQUIRED_RESULT Akonadi::Collection selectedCollection() const;
-    Q_REQUIRED_RESULT Akonadi::Collection::List checkedCollections() const;
-    Q_REQUIRED_RESULT bool isChecked(const Akonadi::Collection &) const;
-    Q_REQUIRED_RESULT Akonadi::Collection currentCalendar() const;
+    [[nodiscard]] Akonadi::Collection selectedCollection() const;
+    [[nodiscard]] Akonadi::Collection::List checkedCollections() const;
+    [[nodiscard]] bool isChecked(const Akonadi::Collection &) const;
+    [[nodiscard]] Akonadi::Collection currentCalendar() const;
 
 Q_SIGNALS:
+    void collectionEnabled(const Akonadi::Collection &);
+    void collectionDisabled(const Akonadi::Collection &);
+
     void resourcesChanged(bool enabled);
     void resourcesAddedRemoved();
     void defaultResourceChanged(const Akonadi::Collection &);
@@ -90,9 +93,12 @@ private Q_SLOTS:
     void onAction(const QModelIndex &index, int action);
     void slotServerSideSubscription();
 
+    void selectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
+
 private:
     Akonadi::EntityTreeModel *entityTreeModel() const;
 
+    CalendarView *mCalendarView = nullptr;
     Akonadi::StandardCalendarActionManager *mActionManager = nullptr;
     Akonadi::EntityTreeView *mCollectionView = nullptr;
     QAbstractProxyModel *mBaseModel = nullptr;
