@@ -90,10 +90,10 @@ void KODialogManager::showSearchDialog()
         mSearchDialog = new SearchDialog(mMainView);
         connect(mMainView->calendar().data(), &Akonadi::ETMCalendar::calendarChanged, mSearchDialog, &SearchDialog::updateView);
         connect(mSearchDialog, &SearchDialog::showIncidenceSignal, mMainView, qOverload<const Akonadi::Item &>(&CalendarView::showIncidence));
-        connect(mSearchDialog, &SearchDialog::editIncidenceSignal, mMainView, [=](const Akonadi::Item &i) {
+        connect(mSearchDialog, &SearchDialog::editIncidenceSignal, mMainView, [this](const Akonadi::Item &i) {
             mMainView->editIncidence(i);
         });
-        connect(mSearchDialog, &SearchDialog::deleteIncidenceSignal, mMainView, [=](const Akonadi::Item &i) {
+        connect(mSearchDialog, &SearchDialog::deleteIncidenceSignal, mMainView, [this](const Akonadi::Item &i) {
             mMainView->deleteIncidence(i, false);
         });
     }
