@@ -231,7 +231,7 @@ KPrefsWidFont::KPrefsWidFont(KConfigSkeleton::ItemFont *item, QWidget *parent, c
     mPreview = new QLabel(sampleText, parent);
     mPreview->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
 
-    mButton = new QPushButton(i18n("Choose..."), parent);
+    mButton = new QPushButton(i18nc("@action:button", "Choose…"), parent);
     connect(mButton, &QPushButton::clicked, this, &Korganizer::KPrefsWidFont::selectFont);
     QString toolTip = mItem->toolTip();
     if (!toolTip.isEmpty()) {
@@ -867,7 +867,7 @@ void KPrefsDialog::slotDefault()
                                            i18n("You are about to set all preferences to default values. "
                                                 "All custom modifications will be lost."),
                                            i18nc("@title:window", "Setting Default Preferences"),
-                                           KGuiItem(i18n("Reset to Defaults")))
+                                           KGuiItem(i18nc("@action:button", "Reset to Defaults")))
         == KMessageBox::Continue) {
         setDefaults();
     }
