@@ -16,7 +16,10 @@ class KItemIconCheckCombo : public KPIM::KCheckComboBox
 {
     Q_OBJECT
 public:
-    enum ViewType { AgendaType = 0, MonthType };
+    enum ViewType {
+        AgendaType = 0,
+        MonthType
+    };
 
     explicit KItemIconCheckCombo(ViewType viewType, QWidget *parent = nullptr);
     ~KItemIconCheckCombo() override;
